Message For You Sir! — Message For You Sir! v0.1.1 documentation

### Navigation

- index
- modules |
- next |
- Message For You Sir! v0.1.1 documentation »

# Message For You Sir!

Date: | 2010-12-21
Version: | 0.1.1
Status: | 3 - Alpha
Author: | Krys Lawrence
Contact: | m4us at krys ca
Copyright: | 2009-2010, Krys Lawrence
License: | GNU Affero General Public License version 3 (AGPLv3+)

## Project Information

### About

Message For You Sir! (m4us) is a coroutine-based concurrent programming library and framework for Python. It is heavily inspired by the BBC Research's brilliant Kamaelia project. In fact, it largely intends to be a reimplementation of most of Kamaelia's core concepts, but be based on Python coroutines instead of generators. It also aims to be cleaner and simpler.

### Features

- Provides coroutine-based inbox/outbox message-passing programming style.
- Provides simple event loop and message routing mechanisms.
- Provides single-thread and thread-based concurrency.
- Promotes loose-coupling and component-based program design.
- Excellent for pipeline-style data transformation systems.
- Supports publish/subscribe style message distribution.
- Works with both plain Python 2.6+ coroutines (`value = (yield)`) and class-based components.
- Much more pythonic than Kamaelia and with magic.
- Clearly defined interfaces for all objects.
- Complete API documentation and very clean source code.
- Extensible with custom schedulers, post offices, message filters, etc.
- Extensible with zope.interface adapters and custom interface implementations.
- Easy to extend to support distributed computing.
- 100% line test coverage and almost 100% branch test coverage with over 500 tests.
- Currently implements equivalents to Kamaelia's Component, ThreadedComponent, Scheduler, Pipeline, Graphline, and Backplane.

### Status

This project is very young and the code should be considered Alpha quality. It has been minimally tested on Linux and Windows, under Python 2.6, but has not yet been seriously tested on any platform. That said, it does have an extensive test suite with almost 100% branch test coverage.

You are welcome to use this project if you like it, and contributions are certainly welcome, but if you are looking for a better supported project with a strong community, then Kamaelia is a the more responsible choice.

### Installation

The easiest way to install this distribution is:

    pip install m4us

or:

    easy_install m4us

Warning

If you use setuptools, distribute will be installed automatically, replacing your setuptools. If this is unacceptable, using virtualenv to isolate the installation is recommended.

### Basic Usage

Documentation is still lacking. For now see A Simple Example for a simple example.

See also the integration tests for additional examples.

### Documentation and Support

Home page:
  http://pypi.python.org/pypi/m4us
Downloads:
  http://pypi.python.org/pypi/m4us#downloads
Documentation:
  http://packages.python.org/m4us
Bug/issue tracker:
  http://bitbucket.org/krys/m4us/issues
Source code repository:
  http://bitbucket.org/krys/m4us

### Contributing

There is always room for improvement in this project and contributions are certainly welcome. The easiest way to contribute is simply to file a bug report in the issue tracker whenever you find a problem or want to suggest an improvement.

If you would like to participate in a more substantial way, check out the issue tracker and To Do Items Index to find out about the work still needs to be done.

Note

If you submit a bug report, patch or other code, you automatically agree to licence the contribution. See Licensing Information for details on contribution licensing.

### Licence

Message For You Sir! is licensed under the GNU Affero General Public License version 3 or later (AGPLv3+). This is free software: you are free to change and redistribute it under certain conditions. There is NO WARRANTY, to the extent permitted by law. For full licensing information, see Licensing Information.

### Credits

m4us was created by Krys Lawrence <m4us at krys ca>.

This project is greatly inspired by Kamaelia. Special thanks goes to the authors of that project.

## Documentation

- A Simple Example
- Licensing Information
  - Project Licence
  - Documentation Licence
  - Licensing of Included 3rd-Party Code
  - Contributions
- API Documentation
  - `m4us`
  - `m4us.api`
  - `m4us.backplanes`
  - `m4us.concurrency`
  - `m4us.interfaces`
  - `m4us.core`
  - `m4us.core.api`
  - `m4us.core.components`
  - `m4us.core.containers`
  - `m4us.core.coroutines`
  - `m4us.core.exceptions`
  - `m4us.core.interfaces`
  - `m4us.core.messages`
  - `m4us.core.postoffices`
  - `m4us.core.schedulers`
  - `m4us.core.utils`
- Appendix A: Full Licence Text

## Indices and Tables

- Glossary
- Index
- Module Index
- To Do Items Index
- Search Page

### Navigation

- index
- modules |
- next |
- Message For You Sir! v0.1.1 documentation »